Class: Aws::WorkSpaces::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkSpaces::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspaces/client.rb,
sig/client.rbs
Overview
An API client for WorkSpaces. To construct a client, you need to configure a :region and :credentials.
client = Aws::WorkSpaces::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptAccountLinkInvitationResponseSuccess, _AssociateConnectionAliasResponseSuccess, _AssociateIpGroupsResponseSuccess, _AssociateWorkspaceApplicationResponseSuccess, _AuthorizeIpRulesResponseSuccess, _CopyWorkspaceImageResponseSuccess, _CreateAccountLinkInvitationResponseSuccess, _CreateConnectClientAddInResponseSuccess, _CreateConnectionAliasResponseSuccess, _CreateIpGroupResponseSuccess, _CreateStandbyWorkspacesResponseSuccess, _CreateTagsResponseSuccess, _CreateUpdatedWorkspaceImageResponseSuccess, _CreateWorkspaceBundleResponseSuccess, _CreateWorkspaceImageResponseSuccess, _CreateWorkspacesPoolResponseSuccess, _CreateWorkspacesResponseSuccess, _DeleteAccountLinkInvitationResponseSuccess, _DeleteClientBrandingResponseSuccess, _DeleteConnectClientAddInResponseSuccess, _DeleteConnectionAliasResponseSuccess, _DeleteIpGroupResponseSuccess, _DeleteTagsResponseSuccess, _DeleteWorkspaceBundleResponseSuccess, _DeleteWorkspaceImageResponseSuccess, _DeployWorkspaceApplicationsResponseSuccess, _DeregisterWorkspaceDirectoryResponseSuccess, _DescribeAccountModificationsResponseSuccess, _DescribeAccountResponseSuccess, _DescribeApplicationAssociationsResponseSuccess, _DescribeApplicationsResponseSuccess, _DescribeBundleAssociationsResponseSuccess, _DescribeClientBrandingResponseSuccess, _DescribeClientPropertiesResponseSuccess, _DescribeConnectClientAddInsResponseSuccess, _DescribeConnectionAliasPermissionsResponseSuccess, _DescribeConnectionAliasesResponseSuccess, _DescribeCustomWorkspaceImageImportResponseSuccess, _DescribeImageAssociationsResponseSuccess, _DescribeIpGroupsResponseSuccess, _DescribeTagsResponseSuccess, _DescribeWorkspaceAssociationsResponseSuccess, _DescribeWorkspaceBundlesResponseSuccess, _DescribeWorkspaceDirectoriesResponseSuccess, _DescribeWorkspaceImagePermissionsResponseSuccess, _DescribeWorkspaceImagesResponseSuccess, _DescribeWorkspaceSnapshotsResponseSuccess, _DescribeWorkspacesConnectionStatusResponseSuccess, _DescribeWorkspacesPoolSessionsResponseSuccess, _DescribeWorkspacesPoolsResponseSuccess, _DescribeWorkspacesResponseSuccess, _DisassociateConnectionAliasResponseSuccess, _DisassociateIpGroupsResponseSuccess, _DisassociateWorkspaceApplicationResponseSuccess, _GetAccountLinkResponseSuccess, _ImportClientBrandingResponseSuccess, _ImportCustomWorkspaceImageResponseSuccess, _ImportWorkspaceImageResponseSuccess, _ListAccountLinksResponseSuccess, _ListAvailableManagementCidrRangesResponseSuccess, _MigrateWorkspaceResponseSuccess, _ModifyAccountResponseSuccess, _ModifyCertificateBasedAuthPropertiesResponseSuccess, _ModifyClientPropertiesResponseSuccess, _ModifyEndpointEncryptionModeResponseSuccess, _ModifySamlPropertiesResponseSuccess, _ModifySelfservicePermissionsResponseSuccess, _ModifyStreamingPropertiesResponseSuccess, _ModifyWorkspaceAccessPropertiesResponseSuccess, _ModifyWorkspaceCreationPropertiesResponseSuccess, _ModifyWorkspacePropertiesResponseSuccess, _ModifyWorkspaceStateResponseSuccess, _RebootWorkspacesResponseSuccess, _RebuildWorkspacesResponseSuccess, _RegisterWorkspaceDirectoryResponseSuccess, _RejectAccountLinkInvitationResponseSuccess, _RestoreWorkspaceResponseSuccess, _RevokeIpRulesResponseSuccess, _StartWorkspacesPoolResponseSuccess, _StartWorkspacesResponseSuccess, _StopWorkspacesPoolResponseSuccess, _StopWorkspacesResponseSuccess, _TerminateWorkspacesPoolResponseSuccess, _TerminateWorkspacesPoolSessionResponseSuccess, _TerminateWorkspacesResponseSuccess, _UpdateConnectClientAddInResponseSuccess, _UpdateConnectionAliasPermissionResponseSuccess, _UpdateRulesOfIpGroupResponseSuccess, _UpdateWorkspaceBundleResponseSuccess, _UpdateWorkspaceImagePermissionResponseSuccess, _UpdateWorkspacesPoolResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_account_link_invitation(params = {}) ⇒ Types::AcceptAccountLinkInvitationResult
Accepts the account link invitation.
-
#associate_connection_alias(params = {}) ⇒ Types::AssociateConnectionAliasResult
Associates the specified connection alias with the specified directory to enable cross-Region redirection.
-
#associate_ip_groups(params = {}) ⇒ Struct
Associates the specified IP access control group with the specified directory.
-
#associate_workspace_application(params = {}) ⇒ Types::AssociateWorkspaceApplicationResult
Associates the specified application to the specified WorkSpace.
-
#authorize_ip_rules(params = {}) ⇒ Struct
Adds one or more rules to the specified IP access control group.
-
#copy_workspace_image(params = {}) ⇒ Types::CopyWorkspaceImageResult
Copies the specified image from the specified Region to the current Region.
-
#create_account_link_invitation(params = {}) ⇒ Types::CreateAccountLinkInvitationResult
Creates the account link invitation.
-
#create_connect_client_add_in(params = {}) ⇒ Types::CreateConnectClientAddInResult
Creates a client-add-in for Connect Customer within a directory.
-
#create_connection_alias(params = {}) ⇒ Types::CreateConnectionAliasResult
Creates the specified connection alias for use with cross-Region redirection.
-
#create_ip_group(params = {}) ⇒ Types::CreateIpGroupResult
Creates an IP access control group.
-
#create_standby_workspaces(params = {}) ⇒ Types::CreateStandbyWorkspacesResult
Creates a standby WorkSpace in a secondary Region.
-
#create_tags(params = {}) ⇒ Struct
Creates the specified tags for the specified WorkSpaces resource.
-
#create_updated_workspace_image(params = {}) ⇒ Types::CreateUpdatedWorkspaceImageResult
Creates a new updated WorkSpace image based on the specified source image.
-
#create_workspace_bundle(params = {}) ⇒ Types::CreateWorkspaceBundleResult
Creates the specified WorkSpace bundle.
-
#create_workspace_image(params = {}) ⇒ Types::CreateWorkspaceImageResult
Creates a new WorkSpace image from an existing WorkSpace.
-
#create_workspaces(params = {}) ⇒ Types::CreateWorkspacesResult
Creates one or more WorkSpaces.
-
#create_workspaces_pool(params = {}) ⇒ Types::CreateWorkspacesPoolResult
Creates a pool of WorkSpaces.
-
#delete_account_link_invitation(params = {}) ⇒ Types::DeleteAccountLinkInvitationResult
Deletes the account link invitation.
-
#delete_client_branding(params = {}) ⇒ Struct
Deletes customized client branding.
-
#delete_connect_client_add_in(params = {}) ⇒ Struct
Deletes a client-add-in for Connect Customer that is configured within a directory.
-
#delete_connection_alias(params = {}) ⇒ Struct
Deletes the specified connection alias.
-
#delete_ip_group(params = {}) ⇒ Struct
Deletes the specified IP access control group.
-
#delete_tags(params = {}) ⇒ Struct
Deletes the specified tags from the specified WorkSpaces resource.
-
#delete_workspace_bundle(params = {}) ⇒ Struct
Deletes the specified WorkSpace bundle.
-
#delete_workspace_image(params = {}) ⇒ Struct
Deletes the specified image from your account.
-
#deploy_workspace_applications(params = {}) ⇒ Types::DeployWorkspaceApplicationsResult
Deploys associated applications to the specified WorkSpace.
-
#deregister_workspace_directory(params = {}) ⇒ Struct
Deregisters the specified directory.
-
#describe_account(params = {}) ⇒ Types::DescribeAccountResult
Retrieves a list that describes the configuration of Bring Your Own License (BYOL) for the specified account.
-
#describe_account_modifications(params = {}) ⇒ Types::DescribeAccountModificationsResult
Retrieves a list that describes modifications to the configuration of Bring Your Own License (BYOL) for the specified account.
-
#describe_application_associations(params = {}) ⇒ Types::DescribeApplicationAssociationsResult
Describes the associations between the application and the specified associated resources.
-
#describe_applications(params = {}) ⇒ Types::DescribeApplicationsResult
Describes the specified applications by filtering based on their compute types, license availability, operating systems, and owners.
-
#describe_bundle_associations(params = {}) ⇒ Types::DescribeBundleAssociationsResult
Describes the associations between the applications and the specified bundle.
-
#describe_client_branding(params = {}) ⇒ Types::DescribeClientBrandingResult
Describes the specified client branding.
-
#describe_client_properties(params = {}) ⇒ Types::DescribeClientPropertiesResult
Retrieves a list that describes one or more specified Amazon WorkSpaces clients.
-
#describe_connect_client_add_ins(params = {}) ⇒ Types::DescribeConnectClientAddInsResult
Retrieves a list of Connect Customer client add-ins that have been created.
-
#describe_connection_alias_permissions(params = {}) ⇒ Types::DescribeConnectionAliasPermissionsResult
Describes the permissions that the owner of a connection alias has granted to another Amazon Web Services account for the specified connection alias.
-
#describe_connection_aliases(params = {}) ⇒ Types::DescribeConnectionAliasesResult
Retrieves a list that describes the connection aliases used for cross-Region redirection.
-
#describe_custom_workspace_image_import(params = {}) ⇒ Types::DescribeCustomWorkspaceImageImportResult
Retrieves information about a WorkSpace BYOL image being imported via ImportCustomWorkspaceImage.
-
#describe_image_associations(params = {}) ⇒ Types::DescribeImageAssociationsResult
Describes the associations between the applications and the specified image.
-
#describe_ip_groups(params = {}) ⇒ Types::DescribeIpGroupsResult
Describes one or more of your IP access control groups.
-
#describe_tags(params = {}) ⇒ Types::DescribeTagsResult
Describes the specified tags for the specified WorkSpaces resource.
-
#describe_workspace_associations(params = {}) ⇒ Types::DescribeWorkspaceAssociationsResult
Describes the associations betweens applications and the specified WorkSpace.
-
#describe_workspace_bundles(params = {}) ⇒ Types::DescribeWorkspaceBundlesResult
Retrieves a list that describes the available WorkSpace bundles.
-
#describe_workspace_directories(params = {}) ⇒ Types::DescribeWorkspaceDirectoriesResult
Describes the available directories that are registered with Amazon WorkSpaces.
-
#describe_workspace_image_permissions(params = {}) ⇒ Types::DescribeWorkspaceImagePermissionsResult
Describes the permissions that the owner of an image has granted to other Amazon Web Services accounts for an image.
-
#describe_workspace_images(params = {}) ⇒ Types::DescribeWorkspaceImagesResult
Retrieves a list that describes one or more specified images, if the image identifiers are provided.
-
#describe_workspace_snapshots(params = {}) ⇒ Types::DescribeWorkspaceSnapshotsResult
Describes the snapshots for the specified WorkSpace.
-
#describe_workspaces(params = {}) ⇒ Types::DescribeWorkspacesResult
Describes the specified WorkSpaces.
-
#describe_workspaces_connection_status(params = {}) ⇒ Types::DescribeWorkspacesConnectionStatusResult
Describes the connection status of the specified WorkSpaces.
-
#describe_workspaces_pool_sessions(params = {}) ⇒ Types::DescribeWorkspacesPoolSessionsResult
Retrieves a list that describes the streaming sessions for a specified pool.
-
#describe_workspaces_pools(params = {}) ⇒ Types::DescribeWorkspacesPoolsResult
Describes the specified WorkSpaces Pools.
-
#disassociate_connection_alias(params = {}) ⇒ Struct
Disassociates a connection alias from a directory.
-
#disassociate_ip_groups(params = {}) ⇒ Struct
Disassociates the specified IP access control group from the specified directory.
-
#disassociate_workspace_application(params = {}) ⇒ Types::DisassociateWorkspaceApplicationResult
Disassociates the specified application from a WorkSpace.
-
#get_account_link(params = {}) ⇒ Types::GetAccountLinkResult
Retrieves account link information.
-
#import_client_branding(params = {}) ⇒ Types::ImportClientBrandingResult
Imports client branding.
-
#import_custom_workspace_image(params = {}) ⇒ Types::ImportCustomWorkspaceImageResult
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces using EC2 Image Builder.
-
#import_workspace_image(params = {}) ⇒ Types::ImportWorkspaceImageResult
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces.
-
#list_account_links(params = {}) ⇒ Types::ListAccountLinksResult
Lists all account links.
-
#list_available_management_cidr_ranges(params = {}) ⇒ Types::ListAvailableManagementCidrRangesResult
Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you can use for the network management interface when you enable Bring Your Own License (BYOL).
-
#migrate_workspace(params = {}) ⇒ Types::MigrateWorkspaceResult
Migrates a WorkSpace from one operating system or bundle type to another, while retaining the data on the user volume.
-
#modify_account(params = {}) ⇒ Types::ModifyAccountResult
Modifies the configuration of Bring Your Own License (BYOL) for the specified account.
-
#modify_certificate_based_auth_properties(params = {}) ⇒ Struct
Modifies the properties of the certificate-based authentication you want to use with your WorkSpaces.
-
#modify_client_properties(params = {}) ⇒ Struct
Modifies the properties of the specified Amazon WorkSpaces clients.
-
#modify_endpoint_encryption_mode(params = {}) ⇒ Struct
Modifies the endpoint encryption mode that allows you to configure the specified directory between Standard TLS and FIPS 140-2 validated mode.
-
#modify_saml_properties(params = {}) ⇒ Struct
Modifies multiple properties related to SAML 2.0 authentication, including the enablement status, user access URL, and relay state parameter name that are used for configuring federation with an SAML 2.0 identity provider.
-
#modify_selfservice_permissions(params = {}) ⇒ Struct
Modifies the self-service WorkSpace management capabilities for your users.
-
#modify_streaming_properties(params = {}) ⇒ Struct
Modifies the specified streaming properties.
-
#modify_workspace_access_properties(params = {}) ⇒ Struct
Specifies which devices and operating systems users can use to access their WorkSpaces.
-
#modify_workspace_creation_properties(params = {}) ⇒ Struct
Modify the default properties used to create WorkSpaces.
-
#modify_workspace_properties(params = {}) ⇒ Struct
Modifies the specified WorkSpace properties.
-
#modify_workspace_state(params = {}) ⇒ Struct
Sets the state of the specified WorkSpace.
-
#reboot_workspaces(params = {}) ⇒ Types::RebootWorkspacesResult
Reboots the specified WorkSpaces.
-
#rebuild_workspaces(params = {}) ⇒ Types::RebuildWorkspacesResult
Rebuilds the specified WorkSpace.
-
#register_workspace_directory(params = {}) ⇒ Types::RegisterWorkspaceDirectoryResult
Registers the specified directory.
-
#reject_account_link_invitation(params = {}) ⇒ Types::RejectAccountLinkInvitationResult
Rejects the account link invitation.
-
#restore_workspace(params = {}) ⇒ Struct
Restores the specified WorkSpace to its last known healthy state.
-
#revoke_ip_rules(params = {}) ⇒ Struct
Removes one or more rules from the specified IP access control group.
-
#start_workspaces(params = {}) ⇒ Types::StartWorkspacesResult
Starts the specified WorkSpaces.
-
#start_workspaces_pool(params = {}) ⇒ Struct
Starts the specified pool.
-
#stop_workspaces(params = {}) ⇒ Types::StopWorkspacesResult
Stops the specified WorkSpaces.
-
#stop_workspaces_pool(params = {}) ⇒ Struct
Stops the specified pool.
-
#terminate_workspaces(params = {}) ⇒ Types::TerminateWorkspacesResult
Terminates the specified WorkSpaces.
-
#terminate_workspaces_pool(params = {}) ⇒ Struct
Terminates the specified pool.
-
#terminate_workspaces_pool_session(params = {}) ⇒ Struct
Terminates the pool session.
-
#update_connect_client_add_in(params = {}) ⇒ Struct
Updates a Connect Customer client add-in.
-
#update_connection_alias_permission(params = {}) ⇒ Struct
Shares or unshares a connection alias with one account by specifying whether that account has permission to associate the connection alias with a directory.
-
#update_rules_of_ip_group(params = {}) ⇒ Struct
Replaces the current rules of the specified IP access control group with the specified rules.
-
#update_workspace_bundle(params = {}) ⇒ Struct
Updates a WorkSpace bundle with a new image.
-
#update_workspace_image_permission(params = {}) ⇒ Struct
Shares or unshares an image with one account in the same Amazon Web Services Region by specifying whether that account has permission to copy the image.
-
#update_workspaces_pool(params = {}) ⇒ Types::UpdateWorkspacesPoolResult
Updates the specified pool.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-workspaces/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5068 5069 5070 |
# File 'lib/aws-sdk-workspaces/client.rb', line 5068 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5071 5072 5073 |
# File 'lib/aws-sdk-workspaces/client.rb', line 5071 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_account_link_invitation(params = {}) ⇒ Types::AcceptAccountLinkInvitationResult
Accepts the account link invitation.
There's currently no unlinking capability after you accept the account linking invitation.
87 |
# File 'sig/client.rbs', line 87
def accept_account_link_invitation: (
|
#associate_connection_alias(params = {}) ⇒ Types::AssociateConnectionAliasResult
Associates the specified connection alias with the specified directory to enable cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
CREATED.
98 |
# File 'sig/client.rbs', line 98
def associate_connection_alias: (
|
#associate_ip_groups(params = {}) ⇒ Struct
Associates the specified IP access control group with the specified directory.
108 |
# File 'sig/client.rbs', line 108
def associate_ip_groups: (
|
#associate_workspace_application(params = {}) ⇒ Types::AssociateWorkspaceApplicationResult
Associates the specified application to the specified WorkSpace.
119 |
# File 'sig/client.rbs', line 119
def associate_workspace_application: (
|
#authorize_ip_rules(params = {}) ⇒ Struct
Adds one or more rules to the specified IP access control group.
This action gives users permission to access their WorkSpaces from the CIDR address ranges specified in the rules.
129 |
# File 'sig/client.rbs', line 129
def authorize_ip_rules: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 |
# File 'lib/aws-sdk-workspaces/client.rb', line 5041 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkSpaces') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspaces' context[:gem_version] = '1.162.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_workspace_image(params = {}) ⇒ Types::CopyWorkspaceImageResult
Copies the specified image from the specified Region to the current Region. For more information about copying images, see Copy a Custom WorkSpaces Image.
In the China (Ningxia) Region, you can copy images only within the same Region.
In Amazon Web Services GovCloud (US), to copy images to and from other Regions, contact Amazon Web Services Support.
Before copying a shared image, be sure to verify that it has been shared from the correct Amazon Web Services account. To determine if an image has been shared and to see the ID of the Amazon Web Services account that owns an image, use the DescribeWorkSpaceImages and DescribeWorkspaceImagePermissions API operations.
145 |
# File 'sig/client.rbs', line 145
def copy_workspace_image: (
|
#create_account_link_invitation(params = {}) ⇒ Types::CreateAccountLinkInvitationResult
Creates the account link invitation.
164 |
# File 'sig/client.rbs', line 164
def create_account_link_invitation: (
|
#create_connect_client_add_in(params = {}) ⇒ Types::CreateConnectClientAddInResult
Creates a client-add-in for Connect Customer within a directory. You can create only one Connect Customer client add-in within a directory.
This client add-in allows WorkSpaces users to seamlessly connect to Connect Customer.
175 |
# File 'sig/client.rbs', line 175
def create_connect_client_add_in: (
|
#create_connection_alias(params = {}) ⇒ Types::CreateConnectionAliasResult
Creates the specified connection alias for use with cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
187 |
# File 'sig/client.rbs', line 187
def create_connection_alias: (
|
#create_ip_group(params = {}) ⇒ Types::CreateIpGroupResult
Creates an IP access control group.
An IP access control group provides you with the ability to control the IP addresses from which users are allowed to access their WorkSpaces. To specify the CIDR address ranges, add rules to your IP access control group and then associate the group with your directory. You can add rules when you create the group or at any time using AuthorizeIpRules.
There is a default IP access control group associated with your directory. If you don't associate an IP access control group with your directory, the default group is used. The default group includes a default rule that allows users to access their WorkSpaces from anywhere. You cannot modify the default IP access control group for your directory.
203 |
# File 'sig/client.rbs', line 203
def create_ip_group: (
|
#create_standby_workspaces(params = {}) ⇒ Types::CreateStandbyWorkspacesResult
Creates a standby WorkSpace in a secondary Region.
227 |
# File 'sig/client.rbs', line 227
def create_standby_workspaces: (
|
#create_tags(params = {}) ⇒ Struct
Creates the specified tags for the specified WorkSpaces resource.
250 |
# File 'sig/client.rbs', line 250
def create_tags: (
|
#create_updated_workspace_image(params = {}) ⇒ Types::CreateUpdatedWorkspaceImageResult
Creates a new updated WorkSpace image based on the specified source image. The new updated WorkSpace image has the latest drivers and other updates required by the Amazon WorkSpaces components.
To determine which WorkSpace images need to be updated with the latest Amazon WorkSpaces requirements, use DescribeWorkspaceImages.
-
Microsoft Windows updates and other application updates are not included in the update process.
-
The source WorkSpace image is not deleted. You can delete the source image after you've verified your new updated image and created a new bundle.
266 |
# File 'sig/client.rbs', line 266
def create_updated_workspace_image: (
|
#create_workspace_bundle(params = {}) ⇒ Types::CreateWorkspaceBundleResult
Creates the specified WorkSpace bundle. For more information about creating WorkSpace bundles, see Create a Custom WorkSpaces Image and Bundle.
284 |
# File 'sig/client.rbs', line 284
def create_workspace_bundle: (
|
#create_workspace_image(params = {}) ⇒ Types::CreateWorkspaceImageResult
Creates a new WorkSpace image from an existing WorkSpace.
318 |
# File 'sig/client.rbs', line 318
def create_workspace_image: (
|
#create_workspaces(params = {}) ⇒ Types::CreateWorkspacesResult
Creates one or more WorkSpaces.
This operation is asynchronous and returns before the WorkSpaces are created.
MANUAL running mode value is only supported by Amazon
WorkSpaces Core. Contact your account team to be allow-listed to use
this value. For more information, see Amazon WorkSpaces Core.
-
You don't need to specify the
PCOIPprotocol for Linux bundles becauseDCV(formerly WSP) is the default protocol for those bundles. -
User-decoupled WorkSpaces are only supported by Amazon WorkSpaces Core.
-
Review your running mode to ensure you are using one that is optimal for your needs and budget. For more information on switching running modes, see Can I switch between hourly and monthly billing?
337 |
# File 'sig/client.rbs', line 337
def create_workspaces: (
|
#create_workspaces_pool(params = {}) ⇒ Types::CreateWorkspacesPoolResult
Creates a pool of WorkSpaces.
365 |
# File 'sig/client.rbs', line 365
def create_workspaces_pool: (
|
#delete_account_link_invitation(params = {}) ⇒ Types::DeleteAccountLinkInvitationResult
Deletes the account link invitation.
397 |
# File 'sig/client.rbs', line 397
def delete_account_link_invitation: (
|
#delete_client_branding(params = {}) ⇒ Struct
Deletes customized client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
After you delete your customized client branding, your login portal reverts to the default client branding.
407 |
# File 'sig/client.rbs', line 407
def delete_client_branding: (
|
#delete_connect_client_add_in(params = {}) ⇒ Struct
Deletes a client-add-in for Connect Customer that is configured within a directory.
417 |
# File 'sig/client.rbs', line 417
def delete_connect_client_add_in: (
|
#delete_connection_alias(params = {}) ⇒ Struct
Deletes the specified connection alias. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
If you will no longer be using a fully qualified domain name (FQDN) as the registration code for your WorkSpaces users, you must take certain precautions to prevent potential security issues. For more information, see Security Considerations if You Stop Using Cross-Region Redirection.
427 |
# File 'sig/client.rbs', line 427
def delete_connection_alias: (
|
#delete_ip_group(params = {}) ⇒ Struct
Deletes the specified IP access control group.
You cannot delete an IP access control group that is associated with a directory.
436 |
# File 'sig/client.rbs', line 436
def delete_ip_group: (
|
#delete_tags(params = {}) ⇒ Struct
Deletes the specified tags from the specified WorkSpaces resource.
445 |
# File 'sig/client.rbs', line 445
def delete_tags: (
|
#delete_workspace_bundle(params = {}) ⇒ Struct
Deletes the specified WorkSpace bundle. For more information about deleting WorkSpace bundles, see Delete a Custom WorkSpaces Bundle or Image.
455 |
# File 'sig/client.rbs', line 455
def delete_workspace_bundle: (
|
#delete_workspace_image(params = {}) ⇒ Struct
Deletes the specified image from your account. To delete an image, you must first delete any bundles that are associated with the image and unshare the image if it is shared with other accounts.
464 |
# File 'sig/client.rbs', line 464
def delete_workspace_image: (
|
#deploy_workspace_applications(params = {}) ⇒ Types::DeployWorkspaceApplicationsResult
Deploys associated applications to the specified WorkSpace
474 |
# File 'sig/client.rbs', line 474
def deploy_workspace_applications: (
|
#deregister_workspace_directory(params = {}) ⇒ Struct
Deregisters the specified directory. This operation is asynchronous and returns before the WorkSpace directory is deregistered. If any WorkSpaces are registered to this directory, you must remove them before you can deregister the directory.
To delete empty directories, see Delete the Directory for Your WorkSpaces. If you delete your Simple AD or AD Connector directory, you can always create a new one when you want to start using WorkSpaces again.
484 |
# File 'sig/client.rbs', line 484
def deregister_workspace_directory: (
|
#describe_account(params = {}) ⇒ Types::DescribeAccountResult
Retrieves a list that describes the configuration of Bring Your Own License (BYOL) for the specified account.
497 |
# File 'sig/client.rbs', line 497
def describe_account: (
|
#describe_account_modifications(params = {}) ⇒ Types::DescribeAccountModificationsResult
Retrieves a list that describes modifications to the configuration of Bring Your Own License (BYOL) for the specified account.
507 |
# File 'sig/client.rbs', line 507
def describe_account_modifications: (
|
#describe_application_associations(params = {}) ⇒ Types::DescribeApplicationAssociationsResult
Describes the associations between the application and the specified associated resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
518 |
# File 'sig/client.rbs', line 518
def describe_application_associations: (
|
#describe_applications(params = {}) ⇒ Types::DescribeApplicationsResult
Describes the specified applications by filtering based on their compute types, license availability, operating systems, and owners.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532
def describe_applications: (
|
#describe_bundle_associations(params = {}) ⇒ Types::DescribeBundleAssociationsResult
Describes the associations between the applications and the specified bundle.
548 |
# File 'sig/client.rbs', line 548
def describe_bundle_associations: (
|
#describe_client_branding(params = {}) ⇒ Types::DescribeClientBrandingResult
Describes the specified client branding. Client branding allows you to customize the log in page of various device types for your users. You can add your company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
564 |
# File 'sig/client.rbs', line 564
def describe_client_branding: (
|
#describe_client_properties(params = {}) ⇒ Types::DescribeClientPropertiesResult
Retrieves a list that describes one or more specified Amazon WorkSpaces clients.
574 |
# File 'sig/client.rbs', line 574
def describe_client_properties: (
|
#describe_connect_client_add_ins(params = {}) ⇒ Types::DescribeConnectClientAddInsResult
Retrieves a list of Connect Customer client add-ins that have been created.
585 |
# File 'sig/client.rbs', line 585
def describe_connect_client_add_ins: (
|
#describe_connection_alias_permissions(params = {}) ⇒ Types::DescribeConnectionAliasPermissionsResult
Describes the permissions that the owner of a connection alias has granted to another Amazon Web Services account for the specified connection alias. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
599 |
# File 'sig/client.rbs', line 599
def describe_connection_alias_permissions: (
|
#describe_connection_aliases(params = {}) ⇒ Types::DescribeConnectionAliasesResult
Retrieves a list that describes the connection aliases used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
612 |
# File 'sig/client.rbs', line 612
def describe_connection_aliases: (
|
#describe_custom_workspace_image_import(params = {}) ⇒ Types::DescribeCustomWorkspaceImageImportResult
Retrieves information about a WorkSpace BYOL image being imported via ImportCustomWorkspaceImage.
634 |
# File 'sig/client.rbs', line 634
def describe_custom_workspace_image_import: (
|
#describe_image_associations(params = {}) ⇒ Types::DescribeImageAssociationsResult
Describes the associations between the applications and the specified image.
644 |
# File 'sig/client.rbs', line 644
def describe_image_associations: (
|
#describe_ip_groups(params = {}) ⇒ Types::DescribeIpGroupsResult
Describes one or more of your IP access control groups.
656 |
# File 'sig/client.rbs', line 656
def describe_ip_groups: (
|
#describe_tags(params = {}) ⇒ Types::DescribeTagsResult
Describes the specified tags for the specified WorkSpaces resource.
668 |
# File 'sig/client.rbs', line 668
def describe_tags: (
|
#describe_workspace_associations(params = {}) ⇒ Types::DescribeWorkspaceAssociationsResult
Describes the associations betweens applications and the specified WorkSpace.
678 |
# File 'sig/client.rbs', line 678
def describe_workspace_associations: (
|
#describe_workspace_bundles(params = {}) ⇒ Types::DescribeWorkspaceBundlesResult
Retrieves a list that describes the available WorkSpace bundles.
You can filter the results using either bundle ID or owner, but not both.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
690 |
# File 'sig/client.rbs', line 690
def describe_workspace_bundles: (
|
#describe_workspace_directories(params = {}) ⇒ Types::DescribeWorkspaceDirectoriesResult
Describes the available directories that are registered with Amazon WorkSpaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
703 |
# File 'sig/client.rbs', line 703
def describe_workspace_directories: (
|
#describe_workspace_image_permissions(params = {}) ⇒ Types::DescribeWorkspaceImagePermissionsResult
Describes the permissions that the owner of an image has granted to other Amazon Web Services accounts for an image.
724 |
# File 'sig/client.rbs', line 724
def describe_workspace_image_permissions: (
|
#describe_workspace_images(params = {}) ⇒ Types::DescribeWorkspaceImagesResult
Retrieves a list that describes one or more specified images, if the image identifiers are provided. Otherwise, all images in the account are described.
737 |
# File 'sig/client.rbs', line 737
def describe_workspace_images: (
|
#describe_workspace_snapshots(params = {}) ⇒ Types::DescribeWorkspaceSnapshotsResult
Describes the snapshots for the specified WorkSpace.
751 |
# File 'sig/client.rbs', line 751
def describe_workspace_snapshots: (
|
#describe_workspaces(params = {}) ⇒ Types::DescribeWorkspacesResult
Describes the specified WorkSpaces.
You can filter the results by using the bundle identifier, directory identifier, or owner, but you can specify only one filter at a time.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def describe_workspaces: (
|
#describe_workspaces_connection_status(params = {}) ⇒ Types::DescribeWorkspacesConnectionStatusResult
Describes the connection status of the specified WorkSpaces.
779 |
# File 'sig/client.rbs', line 779
def describe_workspaces_connection_status: (
|
#describe_workspaces_pool_sessions(params = {}) ⇒ Types::DescribeWorkspacesPoolSessionsResult
Retrieves a list that describes the streaming sessions for a specified pool.
791 |
# File 'sig/client.rbs', line 791
def describe_workspaces_pool_sessions: (
|
#describe_workspaces_pools(params = {}) ⇒ Types::DescribeWorkspacesPoolsResult
Describes the specified WorkSpaces Pools.
805 |
# File 'sig/client.rbs', line 805
def describe_workspaces_pools: (
|
#disassociate_connection_alias(params = {}) ⇒ Struct
Disassociates a connection alias from a directory. Disassociating a connection alias disables cross-Region redirection between two directories in different Regions. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
CREATED.
823 |
# File 'sig/client.rbs', line 823
def disassociate_connection_alias: (
|
#disassociate_ip_groups(params = {}) ⇒ Struct
Disassociates the specified IP access control group from the specified directory.
832 |
# File 'sig/client.rbs', line 832
def disassociate_ip_groups: (
|
#disassociate_workspace_application(params = {}) ⇒ Types::DisassociateWorkspaceApplicationResult
Disassociates the specified application from a WorkSpace.
843 |
# File 'sig/client.rbs', line 843
def disassociate_workspace_application: (
|
#get_account_link(params = {}) ⇒ Types::GetAccountLinkResult
Retrieves account link information.
854 |
# File 'sig/client.rbs', line 854
def get_account_link: (
|
#import_client_branding(params = {}) ⇒ Types::ImportClientBrandingResult
Imports client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
After you import client branding, the default branding experience for the specified platform type is replaced with the imported experience
-
You can import up to 6 MB of data with each request. If your request exceeds this limit, you can import client branding for different platform types using separate requests.
-
In each platform type, the
SupportEmailandSupportLinkparameters are mutually exclusive. You can specify only one parameter for each platform type, but not both. -
Imported data can take up to a minute to appear in the WorkSpaces client.
870 |
# File 'sig/client.rbs', line 870
def import_client_branding: (
|
#import_custom_workspace_image(params = {}) ⇒ Types::ImportCustomWorkspaceImageResult
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces using EC2 Image Builder. The image must be an already licensed image that is in your Amazon Web Services account, and you must own the image. For more information about creating BYOL images, see Bring Your Own Windows Desktop Licenses.
925 |
# File 'sig/client.rbs', line 925
def import_custom_workspace_image: (
|
#import_workspace_image(params = {}) ⇒ Types::ImportWorkspaceImageResult
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces. The image must be an already licensed Amazon EC2 image that is in your Amazon Web Services account, and you must own the image. For more information about creating BYOL images, see Bring Your Own Windows Desktop Licenses.
952 |
# File 'sig/client.rbs', line 952
def import_workspace_image: (
|
#list_account_links(params = {}) ⇒ Types::ListAccountLinksResult
Lists all account links.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
973 |
# File 'sig/client.rbs', line 973
def list_account_links: (
|
#list_available_management_cidr_ranges(params = {}) ⇒ Types::ListAvailableManagementCidrRangesResult
Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you can use for the network management interface when you enable Bring Your Own License (BYOL).
This operation can be run only by Amazon Web Services accounts that
are enabled for BYOL. If your account isn't enabled for BYOL, you'll
receive an AccessDeniedException error.
The management network interface is connected to a secure Amazon WorkSpaces management network. It is used for interactive streaming of the WorkSpace desktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage the WorkSpace.
986 |
# File 'sig/client.rbs', line 986
def list_available_management_cidr_ranges: (
|
#migrate_workspace(params = {}) ⇒ Types::MigrateWorkspaceResult
Migrates a WorkSpace from one operating system or bundle type to another, while retaining the data on the user volume.
The migration process recreates the WorkSpace by using a new root
volume from the target bundle image and the user volume from the last
available snapshot of the original WorkSpace. During migration, the
original D:\Users\%USERNAME% user profile folder is renamed to
D:\Users\%USERNAME%MMddyyTHHmmss%.NotMigrated. A new
D:\Users\%USERNAME% folder is generated by the new OS. Certain
files in the old user profile are moved to the new user profile.
For available migration scenarios, details about what happens during migration, and best practices, see Migrate a WorkSpace.
999 |
# File 'sig/client.rbs', line 999
def migrate_workspace: (
|
#modify_account(params = {}) ⇒ Types::ModifyAccountResult
Modifies the configuration of Bring Your Own License (BYOL) for the specified account.
1010 |
# File 'sig/client.rbs', line 1010
def modify_account: (
|
#modify_certificate_based_auth_properties(params = {}) ⇒ Struct
Modifies the properties of the certificate-based authentication you want to use with your WorkSpaces.
1020 |
# File 'sig/client.rbs', line 1020
def modify_certificate_based_auth_properties: (
|
#modify_client_properties(params = {}) ⇒ Struct
Modifies the properties of the specified Amazon WorkSpaces clients.
1034 |
# File 'sig/client.rbs', line 1034
def modify_client_properties: (
|
#modify_endpoint_encryption_mode(params = {}) ⇒ Struct
Modifies the endpoint encryption mode that allows you to configure the specified directory between Standard TLS and FIPS 140-2 validated mode.
1047 |
# File 'sig/client.rbs', line 1047
def modify_endpoint_encryption_mode: (
|
#modify_saml_properties(params = {}) ⇒ Struct
Modifies multiple properties related to SAML 2.0 authentication, including the enablement status, user access URL, and relay state parameter name that are used for configuring federation with an SAML 2.0 identity provider.
1057 |
# File 'sig/client.rbs', line 1057
def modify_saml_properties: (
|
#modify_selfservice_permissions(params = {}) ⇒ Struct
Modifies the self-service WorkSpace management capabilities for your users. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users.
1072 |
# File 'sig/client.rbs', line 1072
def modify_selfservice_permissions: (
|
#modify_streaming_properties(params = {}) ⇒ Struct
Modifies the specified streaming properties.
1088 |
# File 'sig/client.rbs', line 1088
def modify_streaming_properties: (
|
#modify_workspace_access_properties(params = {}) ⇒ Struct
Specifies which devices and operating systems users can use to access their WorkSpaces. For more information, see Control Device Access.
1117 |
# File 'sig/client.rbs', line 1117
def modify_workspace_access_properties: (
|
#modify_workspace_creation_properties(params = {}) ⇒ Struct
Modify the default properties used to create WorkSpaces.
1146 |
# File 'sig/client.rbs', line 1146
def modify_workspace_creation_properties: (
|
#modify_workspace_properties(params = {}) ⇒ Struct
Modifies the specified WorkSpace properties. For important information about how to modify the size of the root and user volumes, see Modify a WorkSpace.
MANUAL running mode value is only supported by Amazon WorkSpaces
Core. Contact your account team to be allow-listed to use this value.
For more information, see Amazon WorkSpaces Core.
1163 |
# File 'sig/client.rbs', line 1163
def modify_workspace_properties: (
|
#modify_workspace_state(params = {}) ⇒ Struct
Sets the state of the specified WorkSpace.
To maintain a WorkSpace without being interrupted, set the WorkSpace
state to ADMIN_MAINTENANCE. WorkSpaces in this state do not respond
to requests to reboot, stop, start, rebuild, or restore. An AutoStop
WorkSpace in this state is not stopped. Users cannot log into a
WorkSpace in the ADMIN_MAINTENANCE state.
1174 |
# File 'sig/client.rbs', line 1174
def modify_workspace_state: (
|
#reboot_workspaces(params = {}) ⇒ Types::RebootWorkspacesResult
Reboots the specified WorkSpaces.
You cannot reboot a WorkSpace unless its state is AVAILABLE,
UNHEALTHY, or REBOOTING. Reboot a WorkSpace in the REBOOTING
state only if your WorkSpace has been stuck in the REBOOTING state
for over 20 minutes.
This operation is asynchronous and returns before the WorkSpaces have rebooted.
1185 |
# File 'sig/client.rbs', line 1185
def reboot_workspaces: (
|
#rebuild_workspaces(params = {}) ⇒ Types::RebuildWorkspacesResult
Rebuilds the specified WorkSpace.
You cannot rebuild a WorkSpace unless its state is AVAILABLE,
ERROR, UNHEALTHY, STOPPED, or REBOOTING.
Rebuilding a WorkSpace is a potentially destructive action that can result in the loss of data. For more information, see Rebuild a WorkSpace.
This operation is asynchronous and returns before the WorkSpaces have been completely rebuilt.
1199 |
# File 'sig/client.rbs', line 1199
def rebuild_workspaces: (
|
#register_workspace_directory(params = {}) ⇒ Types::RegisterWorkspaceDirectoryResult
Registers the specified directory. This operation is asynchronous and returns before the WorkSpace directory is registered. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.
1214 |
# File 'sig/client.rbs', line 1214
def register_workspace_directory: (
|
#reject_account_link_invitation(params = {}) ⇒ Types::RejectAccountLinkInvitationResult
Rejects the account link invitation.
1246 |
# File 'sig/client.rbs', line 1246
def reject_account_link_invitation: (
|
#restore_workspace(params = {}) ⇒ Struct
Restores the specified WorkSpace to its last known healthy state.
You cannot restore a WorkSpace unless its state is AVAILABLE,
ERROR, UNHEALTHY, or STOPPED.
Restoring a WorkSpace is a potentially destructive action that can result in the loss of data. For more information, see Restore a WorkSpace.
This operation is asynchronous and returns before the WorkSpace is completely restored.
1256 |
# File 'sig/client.rbs', line 1256
def restore_workspace: (
|
#revoke_ip_rules(params = {}) ⇒ Struct
Removes one or more rules from the specified IP access control group.
1265 |
# File 'sig/client.rbs', line 1265
def revoke_ip_rules: (
|
#start_workspaces(params = {}) ⇒ Types::StartWorkspacesResult
Starts the specified WorkSpaces.
You cannot start a WorkSpace unless it has a running mode of
AutoStop or Manual and a state of STOPPED.
1276 |
# File 'sig/client.rbs', line 1276
def start_workspaces: (
|
#start_workspaces_pool(params = {}) ⇒ Struct
Starts the specified pool.
You cannot start a pool unless it has a running mode of AutoStop and
a state of STOPPED.
1289 |
# File 'sig/client.rbs', line 1289
def start_workspaces_pool: (
|
#stop_workspaces(params = {}) ⇒ Types::StopWorkspacesResult
Stops the specified WorkSpaces.
You cannot stop a WorkSpace unless it has a running mode of AutoStop
or Manual and a state of AVAILABLE, IMPAIRED, UNHEALTHY, or
ERROR.
1299 |
# File 'sig/client.rbs', line 1299
def stop_workspaces: (
|
#stop_workspaces_pool(params = {}) ⇒ Struct
Stops the specified pool.
You cannot stop a WorkSpace pool unless it has a running mode of
AutoStop and a state of AVAILABLE, IMPAIRED, UNHEALTHY, or
ERROR.
1312 |
# File 'sig/client.rbs', line 1312
def stop_workspaces_pool: (
|
#terminate_workspaces(params = {}) ⇒ Types::TerminateWorkspacesResult
Terminates the specified WorkSpaces.
Terminating a WorkSpace is a permanent action and cannot be undone. The user's data is destroyed. If you need to archive any user data, contact Amazon Web Services Support before terminating the WorkSpace.
You can terminate a WorkSpace that is in any state except SUSPENDED.
This operation is asynchronous and returns before the WorkSpaces have
been completely terminated. After a WorkSpace is terminated, the
TERMINATED state is returned only briefly before the WorkSpace
directory metadata is cleaned up, so this state is rarely returned. To
confirm that a WorkSpace is terminated, check for the WorkSpace ID by
using DescribeWorkSpaces. If the WorkSpace ID isn't returned,
then the WorkSpace has been successfully terminated.
To delete empty directories, see Delete the Directory for Your WorkSpaces. If you delete your Simple AD or AD Connector directory, you can always create a new one when you want to start using WorkSpaces again.
1322 |
# File 'sig/client.rbs', line 1322
def terminate_workspaces: (
|
#terminate_workspaces_pool(params = {}) ⇒ Struct
Terminates the specified pool.
1335 |
# File 'sig/client.rbs', line 1335
def terminate_workspaces_pool: (
|
#terminate_workspaces_pool_session(params = {}) ⇒ Struct
Terminates the pool session.
1344 |
# File 'sig/client.rbs', line 1344
def terminate_workspaces_pool_session: (
|
#update_connect_client_add_in(params = {}) ⇒ Struct
Updates a Connect Customer client add-in. Use this action to update the name and endpoint URL of a Connect Customer client add-in.
1353 |
# File 'sig/client.rbs', line 1353
def update_connect_client_add_in: (
|
#update_connection_alias_permission(params = {}) ⇒ Struct
Shares or unshares a connection alias with one account by specifying whether that account has permission to associate the connection alias with a directory. If the association permission is granted, the connection alias is shared with that account. If the association permission is revoked, the connection alias is unshared with the account. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
CREATED.
- To delete a connection alias that has been shared, the shared account must first disassociate the connection alias from any directories it has been associated with. Then you must unshare the connection alias from the account it has been shared with. You can delete a connection alias only after it is no longer shared with any accounts or associated with any directories.
1365 |
# File 'sig/client.rbs', line 1365
def update_connection_alias_permission: (
|
#update_rules_of_ip_group(params = {}) ⇒ Struct
Replaces the current rules of the specified IP access control group with the specified rules.
1378 |
# File 'sig/client.rbs', line 1378
def update_rules_of_ip_group: (
|
#update_workspace_bundle(params = {}) ⇒ Struct
Updates a WorkSpace bundle with a new image. For more information about updating WorkSpace bundles, see Update a Custom WorkSpaces Bundle.
Existing WorkSpaces aren't automatically updated when you update the bundle that they're based on. To update existing WorkSpaces that are based on a bundle that you've updated, you must either rebuild the WorkSpaces or delete and recreate them.
1393 |
# File 'sig/client.rbs', line 1393
def update_workspace_bundle: (
|
#update_workspace_image_permission(params = {}) ⇒ Struct
Shares or unshares an image with one account in the same Amazon Web Services Region by specifying whether that account has permission to copy the image. If the copy image permission is granted, the image is shared with that account. If the copy image permission is revoked, the image is unshared with the account.
After an image has been shared, the recipient account can copy the image to other Regions as needed.
In the China (Ningxia) Region, you can copy images only within the same Region.
In Amazon Web Services GovCloud (US), to copy images to and from other Regions, contact Amazon Web Services Support.
For more information about sharing images, see Share or Unshare a Custom WorkSpaces Image.
- Sharing Bring Your Own License (BYOL) images across Amazon Web Services accounts isn't supported at this time in Amazon Web Services GovCloud (US). To share BYOL images across accounts in Amazon Web Services GovCloud (US), contact Amazon Web Services Support.
1403 |
# File 'sig/client.rbs', line 1403
def update_workspace_image_permission: (
|
#update_workspaces_pool(params = {}) ⇒ Types::UpdateWorkspacesPoolResult
Updates the specified pool.
1415 |
# File 'sig/client.rbs', line 1415
def update_workspaces_pool: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5061 5062 5063 |
# File 'lib/aws-sdk-workspaces/client.rb', line 5061 def waiter_names [] end |