Class: Aws::WorkSpaces::Types::ClientProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Describes an Amazon WorkSpaces client.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_experience_policyString

The client experience policy that determines which client experience the user sees. Administrators can set this policy to control the client experience for users in a directory. Valid values include FORCE_CLASSIC, FORCE_UI_2026, and USER_CHOICE.

Returns:



558
559
560
561
562
563
564
# File 'lib/aws-sdk-workspaces/types.rb', line 558

class ClientProperties < Struct.new(
  :reconnect_enabled,
  :log_upload_enabled,
  :client_experience_policy)
  SENSITIVE = []
  include Aws::Structure
end

#log_upload_enabledString

Specifies whether users can upload diagnostic log files of Amazon WorkSpaces client directly to WorkSpaces to troubleshoot issues when using the WorkSpaces client. When enabled, the log files will be sent to WorkSpaces automatically and will be applied to all users in the specified directory.

Returns:



558
559
560
561
562
563
564
# File 'lib/aws-sdk-workspaces/types.rb', line 558

class ClientProperties < Struct.new(
  :reconnect_enabled,
  :log_upload_enabled,
  :client_experience_policy)
  SENSITIVE = []
  include Aws::Structure
end

#reconnect_enabledString

Specifies whether users can cache their credentials on the Amazon WorkSpaces client. When enabled, users can choose to reconnect to their WorkSpaces without re-entering their credentials.

Returns:



558
559
560
561
562
563
564
# File 'lib/aws-sdk-workspaces/types.rb', line 558

class ClientProperties < Struct.new(
  :reconnect_enabled,
  :log_upload_enabled,
  :client_experience_policy)
  SENSITIVE = []
  include Aws::Structure
end