Class: Aws::WorkSpaces::Types::ConnectionAliasAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::ConnectionAliasAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Describes a connection alias association that is used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_account_id ⇒ String
The identifier of the Amazon Web Services account that associated the connection alias with a directory.
-
#association_status ⇒ String
The association status of the connection alias.
-
#connection_identifier ⇒ String
The identifier of the connection alias association.
-
#resource_id ⇒ String
The identifier of the directory associated with a connection alias.
Instance Attribute Details
#associated_account_id ⇒ String
The identifier of the Amazon Web Services account that associated the connection alias with a directory.
720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-workspaces/types.rb', line 720 class ConnectionAliasAssociation < Struct.new( :association_status, :associated_account_id, :resource_id, :connection_identifier) SENSITIVE = [] include Aws::Structure end |
#association_status ⇒ String
The association status of the connection alias.
720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-workspaces/types.rb', line 720 class ConnectionAliasAssociation < Struct.new( :association_status, :associated_account_id, :resource_id, :connection_identifier) SENSITIVE = [] include Aws::Structure end |
#connection_identifier ⇒ String
The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you're configuring your DNS routing policies.
720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-workspaces/types.rb', line 720 class ConnectionAliasAssociation < Struct.new( :association_status, :associated_account_id, :resource_id, :connection_identifier) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the directory associated with a connection alias.
720 721 722 723 724 725 726 727 |
# File 'lib/aws-sdk-workspaces/types.rb', line 720 class ConnectionAliasAssociation < Struct.new( :association_status, :associated_account_id, :resource_id, :connection_identifier) SENSITIVE = [] include Aws::Structure end |