Class: Aws::WorkSpaces::Types::CreateConnectClientAddInRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::CreateConnectClientAddInRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Note:
When making an API call, you may pass CreateConnectClientAddInRequest data as a hash:
{
resource_id: "DirectoryId", # required
name: "AddInName", # required
url: "AddInUrl", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the client add-in.
-
#resource_id ⇒ String
The directory identifier for which to configure the client add-in.
-
#url ⇒ String
The endpoint URL of the Amazon Connect client add-in.
Instance Attribute Details
#name ⇒ String
The name of the client add-in.
503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-workspaces/types.rb', line 503 class CreateConnectClientAddInRequest < Struct.new( :resource_id, :name, :url) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The directory identifier for which to configure the client add-in.
503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-workspaces/types.rb', line 503 class CreateConnectClientAddInRequest < Struct.new( :resource_id, :name, :url) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The endpoint URL of the Amazon Connect client add-in.
503 504 505 506 507 508 509 |
# File 'lib/aws-sdk-workspaces/types.rb', line 503 class CreateConnectClientAddInRequest < Struct.new( :resource_id, :name, :url) SENSITIVE = [] include Aws::Structure end |