Class: Aws::WorkSpaces::Types::CreateWorkspaceImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the new WorkSpace image.

Returns:

  • (String)


1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/aws-sdk-workspaces/types.rb', line 1114

class CreateWorkspaceImageRequest < Struct.new(
  :name,
  :description,
  :workspace_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the new WorkSpace image.

Returns:

  • (String)


1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/aws-sdk-workspaces/types.rb', line 1114

class CreateWorkspaceImageRequest < Struct.new(
  :name,
  :description,
  :workspace_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags that you want to add to the new WorkSpace image. To add tags when you’re creating the image, you must create an IAM policy that grants your IAM user permission to use workspaces:CreateTags.

Returns:



1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/aws-sdk-workspaces/types.rb', line 1114

class CreateWorkspaceImageRequest < Struct.new(
  :name,
  :description,
  :workspace_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The identifier of the source WorkSpace

Returns:

  • (String)


1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/aws-sdk-workspaces/types.rb', line 1114

class CreateWorkspaceImageRequest < Struct.new(
  :name,
  :description,
  :workspace_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end