Class: Aws::WorkSpaces::Types::DeployWorkspaceApplicationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DeployWorkspaceApplicationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force ⇒ Boolean
Indicates whether the force flag is applied for the specified WorkSpace.
-
#workspace_id ⇒ String
The identifier of the WorkSpace.
Instance Attribute Details
#force ⇒ Boolean
Indicates whether the force flag is applied for the specified WorkSpace. When the force flag is enabled, it allows previously failed deployments to be retried.
1626 1627 1628 1629 1630 1631 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1626 class DeployWorkspaceApplicationsRequest < Struct.new( :workspace_id, :force) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the WorkSpace.
1626 1627 1628 1629 1630 1631 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1626 class DeployWorkspaceApplicationsRequest < Struct.new( :workspace_id, :force) SENSITIVE = [] include Aws::Structure end |