Class: Aws::WorkSpaces::Types::DescribeAccountResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dedicated_tenancy_account_typeString

The type of linked account.



1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/aws-sdk-workspaces/types.rb', line 1784

class DescribeAccountResult < Struct.new(
  :dedicated_tenancy_support,
  :dedicated_tenancy_management_cidr_range,
  :dedicated_tenancy_account_type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_tenancy_management_cidr_rangeString

The IP address range, specified as an IPv4 CIDR block, used for the management network interface.

The management network interface is connected to a secure Amazon WorkSpaces management network. It is used for interactive streaming of the WorkSpace desktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage the WorkSpace.



1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/aws-sdk-workspaces/types.rb', line 1784

class DescribeAccountResult < Struct.new(
  :dedicated_tenancy_support,
  :dedicated_tenancy_management_cidr_range,
  :dedicated_tenancy_account_type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_tenancy_supportString

The status of BYOL (whether BYOL is enabled or disabled).



1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/aws-sdk-workspaces/types.rb', line 1784

class DescribeAccountResult < Struct.new(
  :dedicated_tenancy_support,
  :dedicated_tenancy_management_cidr_range,
  :dedicated_tenancy_account_type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The text message to describe the status of BYOL.



1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/aws-sdk-workspaces/types.rb', line 1784

class DescribeAccountResult < Struct.new(
  :dedicated_tenancy_support,
  :dedicated_tenancy_management_cidr_range,
  :dedicated_tenancy_account_type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end