Class: Aws::WorkSpaces::Types::DescribeClientBrandingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DescribeClientBrandingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_id ⇒ String
The directory identifier of the WorkSpace for which you want to view client branding information.
Instance Attribute Details
#resource_id ⇒ String
The directory identifier of the WorkSpace for which you want to view client branding information.
1936 1937 1938 1939 1940 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1936 class DescribeClientBrandingRequest < Struct.new( :resource_id) SENSITIVE = [] include Aws::Structure end |