Class: Aws::WorkSpaces::Types::DescribeConnectionAliasPermissionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DescribeConnectionAliasPermissionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_id ⇒ String
The identifier of the connection alias.
-
#connection_alias_permissions ⇒ Array<Types::ConnectionAliasPermission>
The permissions associated with a connection alias.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#alias_id ⇒ String
The identifier of the connection alias.
2090 2091 2092 2093 2094 2095 2096 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2090 class DescribeConnectionAliasPermissionsResult < Struct.new( :alias_id, :connection_alias_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#connection_alias_permissions ⇒ Array<Types::ConnectionAliasPermission>
The permissions associated with a connection alias.
2090 2091 2092 2093 2094 2095 2096 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2090 class DescribeConnectionAliasPermissionsResult < Struct.new( :alias_id, :connection_alias_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is null when there are no more results to return.
2090 2091 2092 2093 2094 2095 2096 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2090 class DescribeConnectionAliasPermissionsResult < Struct.new( :alias_id, :connection_alias_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |