Class: Aws::WorkSpaces::Types::DescribeWorkspaceBundlesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bundle_idsArray<String>

The identifiers of the bundles. You cannot combine this parameter with any other filter.

Returns:

  • (Array<String>)


2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-workspaces/types.rb', line 2355

class DescribeWorkspaceBundlesRequest < Struct.new(
  :bundle_ids,
  :owner,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. (You received this token from a previous call.)

Returns:

  • (String)


2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-workspaces/types.rb', line 2355

class DescribeWorkspaceBundlesRequest < Struct.new(
  :bundle_ids,
  :owner,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the bundles. You cannot combine this parameter with any other filter.

To describe the bundles provided by Amazon Web Services, specify AMAZON. To describe the bundles that belong to your account, don’t specify a value.

Returns:

  • (String)


2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-workspaces/types.rb', line 2355

class DescribeWorkspaceBundlesRequest < Struct.new(
  :bundle_ids,
  :owner,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end