Class: Aws::WorkSpaces::Types::DescribeWorkspaceImagePermissionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DescribeWorkspaceImagePermissionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_id ⇒ String
The identifier of the image.
-
#image_permissions ⇒ Array<Types::ImagePermission>
The identifiers of the Amazon Web Services accounts that the image has been shared with.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#image_id ⇒ String
The identifier of the image.
2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2492 class DescribeWorkspaceImagePermissionsResult < Struct.new( :image_id, :image_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#image_permissions ⇒ Array<Types::ImagePermission>
The identifiers of the Amazon Web Services accounts that the image has been shared with.
2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2492 class DescribeWorkspaceImagePermissionsResult < Struct.new( :image_id, :image_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is null when there are no more results to return.
2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2492 class DescribeWorkspaceImagePermissionsResult < Struct.new( :image_id, :image_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |