Class: Aws::WorkSpaces::Types::DescribeWorkspacesPoolsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DescribeWorkspacesPoolsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If you received a
NextTokenfrom a previous call that was paginated, provide this token to receive the next set of results. -
#workspaces_pools ⇒ Array<Types::WorkspacesPool>
Information about the WorkSpaces Pools.
Instance Attribute Details
#next_token ⇒ String
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.
2725 2726 2727 2728 2729 2730 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2725 class DescribeWorkspacesPoolsResult < Struct.new( :workspaces_pools, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspaces_pools ⇒ Array<Types::WorkspacesPool>
Information about the WorkSpaces Pools.
2725 2726 2727 2728 2729 2730 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2725 class DescribeWorkspacesPoolsResult < Struct.new( :workspaces_pools, :next_token) SENSITIVE = [] include Aws::Structure end |