Class: Aws::WorkSpaces::Types::ImagePermission
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::ImagePermission
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Describes the Amazon Web Services accounts that have been granted permission to use a shared image. For more information about sharing images, see Share or Unshare a Custom WorkSpaces Image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shared_account_id ⇒ String
The identifier of the Amazon Web Services account that an image has been shared with.
Instance Attribute Details
#shared_account_id ⇒ String
The identifier of the Amazon Web Services account that an image has been shared with.
3083 3084 3085 3086 3087 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3083 class ImagePermission < Struct.new( :shared_account_id) SENSITIVE = [] include Aws::Structure end |