Class: Aws::WorkSpaces::Types::ImageSourceIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::ImageSourceIdentifier
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
ImageSourceIdentifier is a union - when making an API calls you must set exactly one of the members.
ImageSourceIdentifier is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSourceIdentifier corresponding to the set member.
Describes the image import source.
Defined Under Namespace
Classes: Ec2ImageId, Ec2ImportTaskId, ImageBuildVersionArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ec2_image_id ⇒ String
The identifier of the EC2 image.
-
#ec2_import_task_id ⇒ String
The EC2 import task ID to import the image from the Amazon EC2 VM import process.
-
#image_build_version_arn ⇒ String
The ARN of the EC2 Image Builder image.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ec2_image_id ⇒ String
The identifier of the EC2 image.
3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3155 class ImageSourceIdentifier < Struct.new( :ec2_import_task_id, :image_build_version_arn, :ec2_image_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Ec2ImportTaskId < ImageSourceIdentifier; end class ImageBuildVersionArn < ImageSourceIdentifier; end class Ec2ImageId < ImageSourceIdentifier; end class Unknown < ImageSourceIdentifier; end end |
#ec2_import_task_id ⇒ String
The EC2 import task ID to import the image from the Amazon EC2 VM import process.
3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3155 class ImageSourceIdentifier < Struct.new( :ec2_import_task_id, :image_build_version_arn, :ec2_image_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Ec2ImportTaskId < ImageSourceIdentifier; end class ImageBuildVersionArn < ImageSourceIdentifier; end class Ec2ImageId < ImageSourceIdentifier; end class Unknown < ImageSourceIdentifier; end end |
#image_build_version_arn ⇒ String
The ARN of the EC2 Image Builder image.
3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3155 class ImageSourceIdentifier < Struct.new( :ec2_import_task_id, :image_build_version_arn, :ec2_image_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Ec2ImportTaskId < ImageSourceIdentifier; end class ImageBuildVersionArn < ImageSourceIdentifier; end class Ec2ImageId < ImageSourceIdentifier; end class Unknown < ImageSourceIdentifier; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3155 3156 3157 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3155 def unknown @unknown end |