Class: Aws::WorkSpaces::Types::IosClientBrandingAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

The client branding attributes for iOS device types. These attributes are displayed on the iOS client login screen only.

Client branding attributes are public facing. Ensure you do not include sensitive information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The forgotten password link. This is the web address that users can go to if they forget the password for their WorkSpace.

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

#login_messageHash<String,String>

The login message. Specified as a key value pair, in which the key is a locale and the value is the localized message for that locale. The only key supported is en_US. The HTML tags supported include the following: ‘a, b, blockquote, br, cite, code, dd, dl, dt, div, em, i, li, ol, p, pre, q, small, span, strike, strong, sub, sup, u, ul`.

Returns:

  • (Hash<String,String>)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

#logo_2x_urlString

The @2x version of the logo. This is the higher resolution display that offers a scale factor of 2.0 (or @2x). The only image format accepted is a binary data object that is converted from a .png file.

<note markdown=“1”> For more information about iOS image size and resolution, see [Image Size and Resolution ][1] in the *Apple Human Interface Guidelines*.

</note>

[1]: developer.apple.com/design/human-interface-guidelines/ios/icons-and-images/image-size-and-resolution/

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

#logo_3x_urlString

The @3x version of the logo. This is the higher resolution display that offers a scale factor of 3.0 (or @3x).The only image format accepted is a binary data object that is converted from a .png file.

<note markdown=“1”> For more information about iOS image size and resolution, see [Image Size and Resolution ][1] in the *Apple Human Interface Guidelines*.

</note>

[1]: developer.apple.com/design/human-interface-guidelines/ios/icons-and-images/image-size-and-resolution/

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

#logo_urlString

The logo. This is the standard-resolution display that has a 1:1 pixel density (or @1x), where one pixel is equal to one point. The only image format accepted is a binary data object that is converted from a .png file.

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

#support_emailString

The support email. The company’s customer support email address.

<note markdown=“1”> * In each platform type, the SupportEmail and SupportLink

parameters are mutually exclusive. You can specify one parameter
for each platform type, but not both.
</note>

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end

The support link. The link for the company’s customer support page for their WorkSpace.

<note markdown=“1”> * In each platform type, the SupportEmail and SupportLink

parameters are mutually exclusive. You can specify one parameter
for each platform type, but not both.
</note>

Returns:

  • (String)


3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-workspaces/types.rb', line 3546

class IosClientBrandingAttributes < Struct.new(
  :logo_url,
  :logo_2x_url,
  :logo_3x_url,
  :support_email,
  :support_link,
  :forgot_password_link,
  :login_message)
  SENSITIVE = []
  include Aws::Structure
end