Class: Aws::WorkSpaces::Types::MigrateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::MigrateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_id ⇒ String
The identifier of the target bundle type to migrate the WorkSpace to.
-
#source_workspace_id ⇒ String
The identifier of the WorkSpace to migrate from.
Instance Attribute Details
#bundle_id ⇒ String
The identifier of the target bundle type to migrate the WorkSpace to.
3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3790 class MigrateWorkspaceRequest < Struct.new( :source_workspace_id, :bundle_id) SENSITIVE = [] include Aws::Structure end |
#source_workspace_id ⇒ String
The identifier of the WorkSpace to migrate from.
3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-workspaces/types.rb', line 3790 class MigrateWorkspaceRequest < Struct.new( :source_workspace_id, :bundle_id) SENSITIVE = [] include Aws::Structure end |