Class: Aws::WorkSpaces::Types::RegisterWorkspaceDirectoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::RegisterWorkspaceDirectoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_directory_config ⇒ Types::ActiveDirectoryConfig
The active directory config of the directory.
-
#directory_id ⇒ String
The identifier of the directory.
-
#enable_self_service ⇒ Boolean
Indicates whether self-service capabilities are enabled or disabled.
-
#idc_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the identity center instance.
-
#microsoft_entra_config ⇒ Types::MicrosoftEntraConfig
The details about Microsoft Entra config.
-
#subnet_ids ⇒ Array<String>
The identifiers of the subnets for your virtual private cloud (VPC).
-
#tags ⇒ Array<Types::Tag>
The tags associated with the directory.
-
#tenancy ⇒ String
Indicates whether your WorkSpace directory is dedicated or shared.
-
#user_identity_type ⇒ String
The type of identity management the user is using.
-
#workspace_directory_description ⇒ String
Description of the directory to register.
-
#workspace_directory_name ⇒ String
The name of the directory to register.
-
#workspace_type ⇒ String
Indicates whether the directory’s WorkSpace type is personal or pools.
Instance Attribute Details
#active_directory_config ⇒ Types::ActiveDirectoryConfig
The active directory config of the directory.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#directory_id ⇒ String
The identifier of the directory. You cannot register a directory if it does not have a status of Active. If the directory does not have a status of Active, you will receive an InvalidResourceStateException error. If you have already registered the maximum number of directories that you can register with Amazon WorkSpaces, you will receive a ResourceLimitExceededException error. Deregister directories that you are not using for WorkSpaces, and try again.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#enable_self_service ⇒ Boolean
Indicates whether self-service capabilities are enabled or disabled.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#idc_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the identity center instance.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#microsoft_entra_config ⇒ Types::MicrosoftEntraConfig
The details about Microsoft Entra config.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The identifiers of the subnets for your virtual private cloud (VPC). Make sure that the subnets are in supported Availability Zones. The subnets must also be in separate Availability Zones. If these conditions are not met, you will receive an OperationNotSupportedException error.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the directory.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
Indicates whether your WorkSpace directory is dedicated or shared. To use Bring Your Own License (BYOL) images, this value must be set to DEDICATED and your Amazon Web Services account must be enabled for BYOL. If your account has not been enabled for BYOL, you will receive an InvalidParameterValuesException error. For more information about BYOL images, see [Bring Your Own Windows Desktop Images].
[1]: docs.aws.amazon.com/workspaces/latest/adminguide/byol-windows-images.html
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#user_identity_type ⇒ String
The type of identity management the user is using.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#workspace_directory_description ⇒ String
Description of the directory to register.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#workspace_directory_name ⇒ String
The name of the directory to register.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |
#workspace_type ⇒ String
Indicates whether the directory’s WorkSpace type is personal or pools.
4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-workspaces/types.rb', line 4367 class RegisterWorkspaceDirectoryRequest < Struct.new( :directory_id, :subnet_ids, :enable_self_service, :tenancy, :tags, :workspace_directory_name, :workspace_directory_description, :user_identity_type, :idc_instance_arn, :microsoft_entra_config, :workspace_type, :active_directory_config) SENSITIVE = [] include Aws::Structure end |