Class: Aws::WorkSpaces::Types::UnsupportedNetworkConfigurationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::UnsupportedNetworkConfigurationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see [ Configure a VPC for Amazon WorkSpaces].
[1]: docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-vpc.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5088 5089 5090 5091 5092 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5088 class UnsupportedNetworkConfigurationException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |