Class: Aws::WorkSpaces::Types::UpdateResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Describes whether a WorkSpace image needs to be updated with the latest drivers and other components required by Amazon WorkSpaces.

Only Windows 10 WorkSpace images can be programmatically updated at this time.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of whether updates for the WorkSpace image are pending or available.

Returns:



5195
5196
5197
5198
5199
5200
# File 'lib/aws-sdk-workspaces/types.rb', line 5195

class UpdateResult < Struct.new(
  :update_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#update_availableBoolean

Indicates whether updated drivers or other components are available for the specified WorkSpace image.

Returns:



5195
5196
5197
5198
5199
5200
# File 'lib/aws-sdk-workspaces/types.rb', line 5195

class UpdateResult < Struct.new(
  :update_available,
  :description)
  SENSITIVE = []
  include Aws::Structure
end