Class: Aws::WorkSpaces::Types::WorkspaceAccessProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::WorkspaceAccessProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
The device types and operating systems that can be used to access a WorkSpace. For more information, see [Amazon WorkSpaces Client Network Requirements].
[1]: docs.aws.amazon.com/workspaces/latest/adminguide/workspaces-network-requirements.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoint_config ⇒ Types::AccessEndpointConfig
Specifies the configuration for accessing the WorkSpace.
-
#device_type_android ⇒ String
Indicates whether users can use Android and Android-compatible Chrome OS devices to access their WorkSpaces.
-
#device_type_chrome_os ⇒ String
Indicates whether users can use Chromebooks to access their WorkSpaces.
-
#device_type_ios ⇒ String
Indicates whether users can use iOS devices to access their WorkSpaces.
-
#device_type_linux ⇒ String
Indicates whether users can use Linux clients to access their WorkSpaces.
-
#device_type_osx ⇒ String
Indicates whether users can use macOS clients to access their WorkSpaces.
-
#device_type_web ⇒ String
Indicates whether users can access their WorkSpaces through a web browser.
-
#device_type_windows ⇒ String
Indicates whether users can use Windows clients to access their WorkSpaces.
-
#device_type_work_spaces_thin_client ⇒ String
Indicates whether users can access their WorkSpaces through a WorkSpaces Thin Client.
-
#device_type_zero_client ⇒ String
Indicates whether users can use zero client devices to access their WorkSpaces.
Instance Attribute Details
#access_endpoint_config ⇒ Types::AccessEndpointConfig
Specifies the configuration for accessing the WorkSpace.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_android ⇒ String
Indicates whether users can use Android and Android-compatible Chrome OS devices to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_chrome_os ⇒ String
Indicates whether users can use Chromebooks to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_ios ⇒ String
Indicates whether users can use iOS devices to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_linux ⇒ String
Indicates whether users can use Linux clients to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_osx ⇒ String
Indicates whether users can use macOS clients to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_web ⇒ String
Indicates whether users can access their WorkSpaces through a web browser.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_windows ⇒ String
Indicates whether users can use Windows clients to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_work_spaces_thin_client ⇒ String
Indicates whether users can access their WorkSpaces through a WorkSpaces Thin Client.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#device_type_zero_client ⇒ String
Indicates whether users can use zero client devices to access their WorkSpaces.
5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5679 class WorkspaceAccessProperties < Struct.new( :device_type_windows, :device_type_osx, :device_type_web, :device_type_ios, :device_type_android, :device_type_chrome_os, :device_type_zero_client, :device_type_linux, :device_type_work_spaces_thin_client, :access_endpoint_config) SENSITIVE = [] include Aws::Structure end |