Method: Aws::WorkSpaces::Types::WorkspaceImage#created

Defined in:
lib/aws-sdk-workspaces/types.rb

#createdTime

The date when the image was created. If the image has been shared, the Amazon Web Services account that the image has been shared with sees the original creation date of the image.

Returns:



6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
# File 'lib/aws-sdk-workspaces/types.rb', line 6113

class WorkspaceImage < Struct.new(
  :image_id,
  :name,
  :description,
  :operating_system,
  :state,
  :required_tenancy,
  :error_code,
  :error_message,
  :created,
  :owner_account_id,
  :updates,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end