Class: Aws::WorkSpaces::Types::ConnectionAliasAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workspaces/types.rb

Overview

Describes a connection alias association that is used for cross-Region redirection. For more information, see [ Cross-Region Redirection for Amazon WorkSpaces].

[1]: docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_account_idString

The identifier of the Amazon Web Services account that associated the connection alias with a directory.



712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-workspaces/types.rb', line 712

class ConnectionAliasAssociation < Struct.new(
  :association_status,
  :associated_account_id,
  :resource_id,
  :connection_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#association_statusString

The association status of the connection alias.



712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-workspaces/types.rb', line 712

class ConnectionAliasAssociation < Struct.new(
  :association_status,
  :associated_account_id,
  :resource_id,
  :connection_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#connection_identifierString

The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you’re configuring your DNS routing policies.



712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-workspaces/types.rb', line 712

class ConnectionAliasAssociation < Struct.new(
  :association_status,
  :associated_account_id,
  :resource_id,
  :connection_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the directory associated with a connection alias.



712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-workspaces/types.rb', line 712

class ConnectionAliasAssociation < Struct.new(
  :association_status,
  :associated_account_id,
  :resource_id,
  :connection_identifier)
  SENSITIVE = []
  include Aws::Structure
end