Class: Aws::WorkSpaces::Types::CreateWorkspaceImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::CreateWorkspaceImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the new WorkSpace image.
-
#name ⇒ String
The name of the new WorkSpace image.
-
#tags ⇒ Array<Types::Tag>
The tags that you want to add to the new WorkSpace image.
-
#workspace_id ⇒ String
The identifier of the source WorkSpace.
Instance Attribute Details
#description ⇒ String
The description of the new WorkSpace image.
1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1114 class CreateWorkspaceImageRequest < Struct.new( :name, :description, :workspace_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new WorkSpace image.
1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1114 class CreateWorkspaceImageRequest < Struct.new( :name, :description, :workspace_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags that you want to add to the new WorkSpace image. To add tags when you’re creating the image, you must create an IAM policy that grants your IAM user permission to use workspaces:CreateTags.
1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1114 class CreateWorkspaceImageRequest < Struct.new( :name, :description, :workspace_id, :tags) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the source WorkSpace
1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/aws-sdk-workspaces/types.rb', line 1114 class CreateWorkspaceImageRequest < Struct.new( :name, :description, :workspace_id, :tags) SENSITIVE = [] include Aws::Structure end |