Class: Aws::WorkSpaces::Types::DescribeWorkspaceBundlesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::DescribeWorkspaceBundlesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_ids ⇒ Array<String>
The identifiers of the bundles.
-
#next_token ⇒ String
The token for the next set of results.
-
#owner ⇒ String
The owner of the bundles.
Instance Attribute Details
#bundle_ids ⇒ Array<String>
The identifiers of the bundles. You cannot combine this parameter with any other filter.
2355 2356 2357 2358 2359 2360 2361 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2355 class DescribeWorkspaceBundlesRequest < Struct.new( :bundle_ids, :owner, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. (You received this token from a previous call.)
2355 2356 2357 2358 2359 2360 2361 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2355 class DescribeWorkspaceBundlesRequest < Struct.new( :bundle_ids, :owner, :next_token) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the bundles. You cannot combine this parameter with any other filter.
To describe the bundles provided by Amazon Web Services, specify AMAZON. To describe the bundles that belong to your account, don’t specify a value.
2355 2356 2357 2358 2359 2360 2361 |
# File 'lib/aws-sdk-workspaces/types.rb', line 2355 class DescribeWorkspaceBundlesRequest < Struct.new( :bundle_ids, :owner, :next_token) SENSITIVE = [] include Aws::Structure end |