Class: Aws::WorkSpaces::Types::UpdateWorkspaceImagePermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkSpaces::Types::UpdateWorkspaceImagePermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_copy_image ⇒ Boolean
The permission to copy the image.
-
#image_id ⇒ String
The identifier of the image.
-
#shared_account_id ⇒ String
The identifier of the Amazon Web Services account to share or unshare the image with.
Instance Attribute Details
#allow_copy_image ⇒ Boolean
The permission to copy the image. This permission can be revoked only after an image has been shared.
5255 5256 5257 5258 5259 5260 5261 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5255 class UpdateWorkspaceImagePermissionRequest < Struct.new( :image_id, :allow_copy_image, :shared_account_id) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The identifier of the image.
5255 5256 5257 5258 5259 5260 5261 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5255 class UpdateWorkspaceImagePermissionRequest < Struct.new( :image_id, :allow_copy_image, :shared_account_id) SENSITIVE = [] include Aws::Structure end |
#shared_account_id ⇒ String
The identifier of the Amazon Web Services account to share or unshare the image with.
Before sharing the image, confirm that you are sharing to the correct Amazon Web Services account ID.
5255 5256 5257 5258 5259 5260 5261 |
# File 'lib/aws-sdk-workspaces/types.rb', line 5255 class UpdateWorkspaceImagePermissionRequest < Struct.new( :image_id, :allow_copy_image, :shared_account_id) SENSITIVE = [] include Aws::Structure end |